@@ -119,7 +119,7 @@ def plot_all_pairwise(model):
     fig = plt.figure()
     fig.subplots_adjust(wspace=0.4, hspace=0.4)
     # Loop through all pairwise combinations
-    for i, (p0, p1) in enumerate(combinations(model.get_group_nodes(), 2)):
+    for i, (p0, p1) in enumerate(combinations(model.get_group_nodes()['node'], 2)):
         fig.add_subplot(6,6,i+1)
         plt.plot(p0.trace(), p1.trace(), '.')
         (a_s, b_s, r, tt, stderr) = sp.stats.linregress(p0.trace(), p1.trace())
@@ -255,14 +255,14 @@ def post_pred_compare_stats(sampled_stats, data_stats, evals=None):
     for stat_name in sampled_stats:
         #update NaN column with the no. of NaNs and remove them
         s = sampled_stats[stat_name]
-        results.ix[stat_name]['NaN'] = sum(pd.isnull(s))
+        results.ix[stat_name, 'NaN'] = sum(pd.isnull(s))
         s = s[np.isfinite(s)]
         if len(s) == 0:
             continue
         #evaluate
         for eval_name, func in evals.iteritems():
             value = func(s, data_stats[stat_name])
-            results.ix[stat_name][eval_name] = value
+            results.ix[stat_name, eval_name] = value
 
     return results.drop('NaN', axis=1)
 
@@ -278,7 +278,7 @@ def _post_pred_generate(bottom_node, samples=500, data=None, append_data=False):
         # Generate data from bottom node
         sampled_data = bottom_node.random()
         if append_data and data is not None:
-            sampled_data = sampled_data.join(data, lsuffix='_sampled')
+            sampled_data = sampled_data.join(data.reset_index(), lsuffix='_sampled')
         datasets.append(sampled_data)
 
     return datasets
@@ -482,7 +482,7 @@ def _plot_posterior_pdf_node(bottom_node, axis, value_range=None, samples=10, bi
     axis.set_ylim(bottom=0) # Likelihood and histogram can only be positive
 
 def plot_posterior_predictive(model, plot_func=None, required_method='pdf', columns=None, save=False, path=None,
-                              figsize=(8,6), format='png', **kwargs):
+                              figsize=(8,6), format='png', num_subjs=None, **kwargs):
     """Plot the posterior predictive distribution of a kabuki hierarchical model.
 
     :Arguments:
@@ -546,7 +546,9 @@ def plot_posterior_predictive(model, plot_func=None, required_method='pdf', colu
         fig.subplots_adjust(top=0.9, hspace=.4, wspace=.3)
 
         # Plot individual subjects (if present)
+        i = 0
         for subj_i, (node_name, bottom_node) in enumerate(nodes.iterrows()):
+            i += 1
             if not hasattr(bottom_node['node'], required_method):
                 continue # skip nodes that do not define the required_method
 
@@ -556,6 +558,9 @@ def plot_posterior_predictive(model, plot_func=None, required_method='pdf', colu
 
             plot_func(bottom_node['node'], ax, **kwargs)
 
+            if num_subjs is not None and num_subjs >= i:
+                break
+
         # Save figure if necessary
         if save:
             fname = 'ppq_' + '.'.join(tag)
